==> senior_design_system-0.10.13.tar.gz: example/lib/main.dart <==
import 'package:example/views/evaluation.exemple.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'views/action_button.example.dart';
import 'views/animation.example.dart';
import 'views/balance.example.dart';
import 'views/bottom_sheet.example.dart';
import 'views/button.example.dart';
import 'views/card.example.dart';
import 'views/colorful_header_structure.example.dart';
import 'views/checkbox.example.dart';
import 'views/dropdown_button.example.dart';
import 'views/expansion_panel.example.dart';
import 'views/info_card.example.dart';
import 'views/quotes_example.dart';
import 'views/loading.example.dart';
import 'views/menu_list_item_example.dart';
import 'views/profile_picture_example.dart';
import 'views/radio_button.example.dart';
import 'views/rating.example.dart';
import 'views/modal.example.dart';
import 'views/snackbar.example.dart';
import 'views/square_buttons_menu.example.dart';
import 'views/switch.example.dart';
import 'views/navigation.example.dart';
import 'views/text_field.example.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'Senior Design System Showcase',
      home: HomePage(),
    );
  }
}

class HomePage extends StatelessWidget {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();
  final PageController _pageController = PageController();
  final Map<String, Widget> _pages = {
    'Action Button': ActionButtonExample(),
    'Animation': AnimationExample(),
    'App Bar/Tab Bar/Bottom Bar': NavigationExample(),
    'Balance': BalanceExample(),
    'Bottom Sheet': BottomSheetExample(),
    'Button': ButtonExample(),
    'Card': CardExample(),
    'Checkbox': CheckboxExample(),
    'Dropdown Button': DropdownButtonExample(),
    'Expansion Panel': ExpansionPanelExample(),
    'Evaluation': EvaluationExemple(),
    'Info Card': InfoCardExample(),
    'Loading': LoadingExample(),
    'Menu List Item': MenuListItemExample(),
    'Modal': ModalExample(),
    'Profile Picture': ProfilePictureExample(),
    'Quotes': QuotesExample(),
    'Radio Button': RadioButtonExample(),
    'Rating': RatingExample(),
    'Screen Appbar': ColorfulHeaderStructureExample(),
    'Snack bar': SnackbarExample(),
    'Square Buttons Menu': SquareButtonsMenuExample(),
    'Switch': SwitchExample(),
    'Text Field': TextFieldExample(),
  };

  HomePage({
    Key? key,
  }) : super(key: key);

  ListView _getListViewMenu() {
    return ListView(
      children: _pages.keys
          .toList()
          .asMap()
          .map((pos, title) => MapEntry(
              title,
              ListTile(
                title: Text(title),
                onTap: () => _jumpToPage(page: pos),
              )))
          .values
          .toList(),
    );
  }

  void _jumpToPage({required int page}) {
    _pageController.jumpToPage(page);
  }

  void _showSnackbar(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.message(
        message: 'Não tem nenhuma ação vinculada a este ícone',
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    int _pageIdx = 0;

    return Scaffold(
      key: _scaffoldKey,
      appBar: SeniorAppBarPage(
        title: _pages.keys.toList()[_pageIdx],
        leading: SeniorAppBarAction(
          icon: FontAwesomeIcons.bars,
          onPressed: () => _scaffoldKey.currentState!.openDrawer(),
        ),
        actions: [
          SeniorAppBarAction(
            icon: FontAwesomeIcons.solidHeart,
            onPressed: () => _showSnackbar(context),
          ),
          SeniorAppBarAction(
            icon: FontAwesomeIcons.search,
            onPressed: () => _showSnackbar(context),
          ),
        ],
      ),
      drawer: Drawer(child: _getListViewMenu()),
      body: PageView.builder(
        controller: _pageController,
        itemBuilder: (context, position) => _pages.values.toList()[position],
        itemCount: _pages.length,
      ),
    );
  }
}

==> senior_design_system-0.14.0.tar.gz: example/lib/main.dart <==
import 'package:example/views/evaluation.exemple.dart';
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'views/action_button.example.dart';
import 'views/animation.example.dart';
import 'views/balance.example.dart';
import 'views/bottom_sheet.example.dart';
import 'views/button.example.dart';
import 'views/card.example.dart';
import 'views/colorful_header_structure.example.dart';
import 'views/checkbox.example.dart';
import 'views/draggable_list.example.dart';
import 'views/dropdown_button.example.dart';
import 'views/expansion_panel.example.dart';
import 'views/info_card.example.dart';
import 'views/image_crop.example.dart';
import 'views/quotes_example.dart';
import 'views/loading.example.dart';
import 'views/menu_list_item_example.dart';
import 'views/profile_picture_example.dart';
import 'views/radio_button.example.dart';
import 'views/rating.example.dart';
import 'views/message_card.example.dart';
import 'views/modal.example.dart';
import 'views/snackbar.example.dart';
import 'views/square_buttons_menu.example.dart';
import 'views/switch.example.dart';
import 'views/navigation.example.dart';
import 'views/notification_list.example.dart';
import 'views/text_field.example.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'Senior Design System Showcase',
      home: HomePage(),
    );
  }
}

class HomePage extends StatelessWidget {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();
  final PageController _pageController = PageController();
  final Map<String, Widget> _pages = {
    'Action Button': ActionButtonExample(),
    'Animation': AnimationExample(),
    'App Bar/Tab Bar/Bottom Bar': NavigationExample(),
    'Balance': BalanceExample(),
    'Bottom Sheet': BottomSheetExample(),
    'Button': ButtonExample(),
    'Card': CardExample(),
    'Checkbox': CheckboxExample(),
    'Draggable List': DraggableListExample(),
    'Dropdown Button': DropdownButtonExample(),
    'Expansion Panel': ExpansionPanelExample(),
    'Evaluation': EvaluationExemple(),
    'Image Cropper': ImageCropperExample(),
    'Info Card': InfoCardExample(),
    'Loading': LoadingExample(),
    'Menu List Item': MenuListItemExample(),
    'Message Card': MessageCardExample(),
    'Modal': ModalExample(),
    'Notification List': NotificationListExample(),
    'Profile Picture': ProfilePictureExample(),
    'Quotes': QuotesExample(),
    'Radio Button': RadioButtonExample(),
    'Rating': RatingExample(),
    'Screen Appbar': ColorfulHeaderStructureExample(),
    'Snack bar': SnackbarExample(),
    'Square Buttons Menu': SquareButtonsMenuExample(),
    'Switch': SwitchExample(),
    'Text Field': TextFieldExample(),
  };

  HomePage({
    Key? key,
  }) : super(key: key);

  ListView _getListViewMenu() {
    return ListView(
      children: _pages.keys
          .toList()
          .asMap()
          .map((pos, title) => MapEntry(
              title,
              ListTile(
                title: Text(title),
                onTap: () => _jumpToPage(page: pos),
              )))
          .values
          .toList(),
    );
  }

  void _jumpToPage({required int page}) {
    _pageController.jumpToPage(page);
  }

  void _showSnackbar(BuildContext context) {
    ScaffoldMessenger.of(context).showSnackBar(
      SeniorSnackBar.message(
        message: 'Não tem nenhuma ação vinculada a este ícone',
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    int _pageIdx = 0;

    return Scaffold(
      key: _scaffoldKey,
      appBar: SeniorAppBarPage(
        title: _pages.keys.toList()[_pageIdx],
        leading: SeniorAppBarAction(
          icon: FontAwesomeIcons.bars,
          onPressed: () => _scaffoldKey.currentState!.openDrawer(),
        ),
        actions: [
          SeniorAppBarAction(
            icon: FontAwesomeIcons.solidHeart,
            onPressed: () => _showSnackbar(context),
          ),
          SeniorAppBarAction(
            icon: FontAwesomeIcons.search,
            onPressed: () => _showSnackbar(context),
          ),
        ],
      ),
      drawer: Drawer(child: _getListViewMenu()),
      body: PageView.builder(
        controller: _pageController,
        itemBuilder: (context, position) => _pages.values.toList()[position],
        itemCount: _pages.length,
      ),
    );
  }
}
